@@ -19,6 +19,9 @@ from napoleontoolbox.forecasting import standard_mean_model_wrapper
 from napoleontoolbox.forecasting import deterministic_sharpe_optim_model_wrapper
 from napoleontoolbox.forecasting import to_weighted_mean_model_wrapper
 from napoleontoolbox.forecasting import max_occurence_model_wrapper
+from napoleontoolbox.forecasting import erc_allocation_model_wrapper
+from napoleontoolbox.forecasting import mvp_allocation_model_wrapper
+from napoleontoolbox.forecasting import mvp_uc_allocation_model_wrapper
 
 from abc import ABC, abstractmethod
 
@@ -42,6 +45,12 @@ def instantiate_model(method):
         return deterministic_sharpe_optim_model_wrapper.DeterministicSharpeOptimModel()
     if method == 'max_occurence':
         return max_occurence_model_wrapper.MaxOccurenceModel()
+    if method == 'erc_allocation_model':
+        return erc_allocation_model_wrapper.ERC_Allocation_Model()
+    if method == 'mvp_allocation_model':
+        return mvp_allocation_model_wrapper.MVP_Allocation_Model()
+    if method == 'mvp_uc_allocation_model':
+        return mvp_uc_allocation_model_wrapper.MVP_uc_Allocation_Model()
 
 
 
