@@ -45,14 +45,17 @@ class AbstractRunner(ABC):
         self.db_path_suffix = db_path_suffix
         self.db_path_name = launcher_utility.get_database_name(user, frequence, underlying, algo, starting_date, running_date, db_path_suffix)
 
-        if not self.recompute_all:
-            saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
-                                                                     local_root_directory=local_root_directory, user=user,
-                                                                     db_path_name=self.db_path_name)
-            self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
-        else:
-            self.precomputed_results_df, self.precomputed_signals_df  = None, None
-
+        # if not self.recompute_all:
+        #     saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
+        #                                                              local_root_directory=local_root_directory, user=user,
+        #                                                              db_path_name=self.db_path_name)
+        #     self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
+        # else:
+        #     self.precomputed_results_df, self.precomputed_signals_df  = None, None
+        saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
+                                                                 local_root_directory=local_root_directory, user=user,
+                                                                 db_path_name=self.db_path_name)
+        self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
     @abstractmethod
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs, normalization):
         pass
@@ -108,6 +111,12 @@ class EnsemblingSignalRunner(AbstractRunner):
             if self.recompute_all:
                 print('Launching computation with parameters : '+run_json_string)
                 print('Signal number '+str(counter))
+                try:
+                    testing_presence_df = self.precomputed_results_df[me_signal]
+                except KeyError:
+                    print('cannot read ', me_signal)
+                    continue
+
                 if signal_type == 'long_only':
                     freqly_df['signal']=1.
                 else:
@@ -118,7 +127,7 @@ class EnsemblingSignalRunner(AbstractRunner):
                     signal_generation_method_to_call = getattr(signal_generator, signal_type)
                     freqly_df = signal_utility.roll_wrapper(freqly_df, lookback_window, self.skipping_size,
                                               lambda x: signal_generation_method_to_call(data=x, **params), trigger)
-                    freqly_df = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs, normalization = normalization)
+                    freqly_df, _ = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs, normalization = normalization)
             else :
                 if self.add_turn_over:
                     raise Exception('to add turn over, you have to recompute all')
