@@ -27,6 +27,16 @@ def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
         params_list.append(params)
     return params_list
 
+def unjsonize_list_run_results_list(signals_list):
+    print('signals list size '+str(len(signals_list)))
+    params_list = []
+    for me_signal in signals_list:
+        ## idiosyncratic run itself
+        run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
+        params = json.loads(run_json_string)
+        params_list.append(params)
+    return params_list
+
 def convert_to_sql_column_format(run):
     run = run.replace('[', 'ccg')
     run = run.replace(']', 'ccd')
@@ -345,3 +355,18 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
     sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=period, from_ret=True)
     return hourly_df, sharpe_strat, sharpe_strat_without, sharpe_under
 
+
+def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnover = False):
+    results_df = pd.concat([signals_df, close_df], axis=1).reindex(signals_df.index)
+    signals_returns_df = None
+    for sig in results_df.columns:
+        if 'signal' in sig:
+            temp_df = results_df[['close', sig]].copy()
+            temp_df = temp_df.rename(columns={sig: "signal"}, errors="raise")
+            freqly_df, _ = signal_utility.reconstitute_signal_perf(data=temp_df, transaction_cost=transac_cost,
+                                                                   print_turnover=print_turnover)
+            if signals_returns_df is None:
+                signals_returns_df = freqly_df[['perf_return']].rename(columns={'perf_return': sig})
+            else:
+                signals_returns_df[sig] = freqly_df.perf_return
+    return signals_returns_df
\ No newline at end of file
